sqlobject.inheritance.tests.test\_deep\_inheritance module
==========================================================

.. automodule:: sqlobject.inheritance.tests.test_deep_inheritance
    :members:
    :undoc-members:
    :show-inheritance:
